AuthRetryableFetchException class

Inheritance

Constructors

AuthRetryableFetchException({String message = 'AuthRetryableFetchException', String? statusCode})

Properties

code → String?
Error code associated with the error. Most errors coming from HTTP responses will have a code, though some errors that occur before a response is received will not have one present. In that case statusCode will also be null.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
Human readable error message associated with the error.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → String?
HTTP status code that caused the error.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited