OAuthAuthorizedClient class

OAuth client object returned from the OAuth 2.1 server when the client is authorized.

Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.

Constructors

OAuthAuthorizedClient({required String clientId, String? clientName})
const
OAuthAuthorizedClient.fromJson(Map<String, dynamic> json)
factory

Properties

clientId → String
Unique identifier for the OAuth client
final
clientName → String?
Human-readable name of the OAuth client
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited