SignedUrlFailure class final

A failed SignedUrlResult: the path could not be signed (e.g. the file does not exist).

Inheritance

Constructors

SignedUrlFailure({required String path, required String error})
const

Properties

error → String
The reason the URL could not be created.
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
The requested file path.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited