SortOrder class

Describes how a table is sorted when written.

Constructors

SortOrder({required int orderId, required List<SortField> fields})
const
SortOrder.fromJson(Map<String, dynamic> json)
factory

Properties

fields → List<SortField>
final
hashCode → int
The hash code for this object.
no setterinherited
orderId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited