StructType class

A nested struct type containing fields.

Inheritance

Constructors

StructType({required List<TableField> fields})
const
StructType.fromJson(Map<String, dynamic> json)
factory

Properties

fields → List<TableField>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited