PaginatedFile class
A file entry returned by StorageFileApi.listPaginated.
Constructors
Properties
- createdAt → String?
-
The creation timestamp.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
The unique identifier of the file.
final
- key → String?
-
The full object key/path.
final
-
metadata
→ Map<
String, dynamic> ? -
The file metadata, including size and mimetype.
nullwhen not yet set.final - name → String
-
The file name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → String?
-
The last update timestamp.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited