StorageVectorIndexApi class
Vector data operations scoped to a single index within a bucket.
Obtain an instance through StorageVectorBucketApi.index.
- Annotations
-
- @experimental
Properties
- bucketName → String
-
The name of the vector bucket these operations are scoped to.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexName → String
-
The name of the index these operations are scoped to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteVectors(
List< String> keys) → Future<void> -
Deletes vectors by their
keys. -
getVectors(
{required List< String> keys, bool? returnData, bool? returnMetadata}) → Future<List< VectorMatch> > -
Retrieves vectors by their
keys. -
listVectors(
{int? maxResults, String? nextToken, bool? returnData, bool? returnMetadata, int? segmentCount, int? segmentIndex}) → Future< VectorList> - Lists vectors in this index with pagination.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putVectors(
List< Vector> vectors) → Future<void> -
Inserts or updates a batch of
vectorsin this index. -
queryVectors(
{required List< double> queryVector, int? topK, Map<String, dynamic> ? filter, bool? returnDistance, bool? returnMetadata}) → Future<VectorQueryResult> -
Searches this index for the vectors most similar to
queryVector. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited