VectorBucket class
Metadata describing a vector bucket.
- Annotations
-
- @experimental
Constructors
- VectorBucket({required String name, DateTime? creationTime, VectorBucketEncryption? encryption})
-
const
-
VectorBucket.fromJson(Map<
String, dynamic> json) -
factory
Properties
- creationTime → DateTime?
-
When the bucket was created, in UTC.
nullwhen the server does not include it (for example in list responses).final - encryption → VectorBucketEncryption?
-
The bucket's encryption configuration, when present.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The unique name of the vector bucket.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited